enablePolling property
bool
get
enablePolling
Gets status of polling, true if polling is enable, otherwise false.
Defaults to true.
Implementation
static bool get enablePolling => _enablePolling;
Gets status of polling, true if polling is enable, otherwise false.
Defaults to true.
static bool get enablePolling => _enablePolling;